==> pytde_14.1.0.orig.tar.xz: pytde-trinity-14.1.0/examples/pytde-sampler/dialogs/color.py <==
iconName = 'colorize'
labelText = 'KColorDialog'


from PyTQt.tqt import TQFrame, TQHBoxLayout, TQVBoxLayout, SIGNAL
from tdecore import i18n
from tdeui import KPushButton, KColorDialog, KColorPatch, KTextEdit


helpText = ("TDE provides a nifty common color selection dialog."
            "The color selection in the dialog is tracked via a SIGNAL "
            "connected to the KColorPatch area below.")


class MainFrame(TQFrame):
    def __init__(self, parent=None):
        TQFrame.__init__(self, parent)
        self.button = KPushButton(i18n('Show Color Dialog'), self)
        self.help = KTextEdit(helpText, '', self)
        self.patch = KColorPatch(self)
        layout = TQVBoxLayout(self, 4)
        layout.addWidget(self.help)
        buttonlayout = TQHBoxLayout(layout, 4)
        buttonlayout.addWidget(self.button)
        buttonlayout.addStretch(1)
        layout.addWidget(self.patch, 10)
        layout.addStretch(1)
        self.connect(self.button, SIGNAL('clicked()'), self.showColorDialog)

    def showColorDialog(self):
        dlg = KColorDialog(self)

        ## this connection is made so that there's a default color
        self.connect(dlg, SIGNAL('colorSelected(const TQColor &)'), 
                     self.patch.setPaletteBackgroundColor)
        dlg.setColor(self.patch.paletteBackgroundColor())

        ## this connection is the one that changes the patch color to match 
        ## the color selected in the dialog
        self.connect(dlg, SIGNAL('colorSelected(const TQColor &)'), 
                     self.patch.setColor)
        dlg.exec_loop()

==> pytde_14.1.5.orig.tar.xz: pytde-trinity-14.1.5/examples/pytde-sampler/dialogs/color.py <==
iconName = 'colorize'
labelText = 'KColorDialog'


from PyTQt.tqt import TQFrame, TQHBoxLayout, TQVBoxLayout, TQ_SIGNAL
from tdecore import i18n
from tdeui import KPushButton, KColorDialog, KColorPatch, KTextEdit


helpText = ("TDE provides a nifty common color selection dialog."
            "The color selection in the dialog is tracked via a TQ_SIGNAL "
            "connected to the KColorPatch area below.")


class MainFrame(TQFrame):
    def __init__(self, parent=None):
        TQFrame.__init__(self, parent)
        self.button = KPushButton(i18n('Show Color Dialog'), self)
        self.help = KTextEdit(helpText, '', self)
        self.patch = KColorPatch(self)
        layout = TQVBoxLayout(self, 4)
        layout.addWidget(self.help)
        buttonlayout = TQHBoxLayout(layout, 4)
        buttonlayout.addWidget(self.button)
        buttonlayout.addStretch(1)
        layout.addWidget(self.patch, 10)
        layout.addStretch(1)
        self.connect(self.button, TQ_SIGNAL('clicked()'), self.showColorDialog)

    def showColorDialog(self):
        dlg = KColorDialog(self)

        ## this connection is made so that there's a default color
        self.connect(dlg, TQ_SIGNAL('colorSelected(const TQColor &)'), 
                     self.patch.setPaletteBackgroundColor)
        dlg.setColor(self.patch.paletteBackgroundColor())

        ## this connection is the one that changes the patch color to match 
        ## the color selected in the dialog
        self.connect(dlg, TQ_SIGNAL('colorSelected(const TQColor &)'), 
                     self.patch.setColor)
        dlg.exec_loop()
